@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.25.4.1 2005/10/27 20:49:59 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.27 2005/11/05 21:59:10 chpe Exp $
  */
 
 #include "config.h"
@@ -339,15 +339,6 @@ static const GtkActionEntry action_entries_2 [] =
 	  G_CALLBACK (view_certificate_cb) }
 };
 
-static void
-free_window_data (WindowData *data)
-{
-	if (data) {
-		g_object_unref (data->action_group);
-		g_free (data);
-	}
-}
-
 static void
 impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
@@ -392,7 +383,8 @@ impl_attach_window (EphyExtension *ext,
 	gtk_action_group_add_actions (action_group, action_entries_2,
 				      G_N_ELEMENTS (action_entries_2), window);
 
-	gtk_ui_manager_insert_action_group (manager, action_group, 0);
+	gtk_ui_manager_insert_action_group (manager, action_group, -1);
+	g_object_unref (win_data->action_group);
 
 	win_data->ui_id = ui_id = gtk_ui_manager_new_merge_id (manager);
 
@@ -419,7 +411,7 @@ impl_attach_window (EphyExtension *ext,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, win_data,
-				(GDestroyNotify) free_window_data);
+				(GDestroyNotify) g_free);
 
 	/* Synchronize */
 	if (GTK_WIDGET_REALIZED (window))
