@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.32 2005/08/04 21:29:57 jframeau Exp $
+ *  $Id: mozilla-helpers.cpp,v 1.33 2005/12/22 10:25:45 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -114,8 +114,8 @@ private:
                     nsIDOMHTMLElement *aHTMLElement);
   void ProcessAppletNode (nsIDOMHTMLAppletElement *aElement);
   void ProcessAreaNode (nsIDOMHTMLAreaElement *aElement);
-  void PageInfoHelper::ProcessEmbedNodeHelper (const nsEmbedString &aUrl, 
-  				               nsIDOMHTMLEmbedElement *aElement);
+  void ProcessEmbedNodeHelper (const nsEmbedString &aUrl, 
+  		               nsIDOMHTMLEmbedElement *aElement);
   void ProcessEmbedNode (nsIDOMHTMLEmbedElement *aElement);
   void ProcessFormNode (nsIDOMHTMLFormElement *aElement);
   void ProcessImageNode (nsIDOMHTMLImageElement *aElement);
